Hypr. |master-travis| |master-coveralls|
========================================

The security-oriented framework to build your micro-services.


.. |master-coveralls| image:: https://coveralls.io/repos/github/project-hypr/hypr2/badge.svg?branch=master
   :target: https://coveralls.io/github/project-hypr/hypr2?branch=master

.. |master-travis| image:: https://travis-ci.org/project-hypr/hypr2.svg?branch=master
   :target: https://travis-ci.org/project-hypr/hypr2
